@@ -113,10 +113,6 @@ Do you want to save your changes?</source>
 Do you want to overwrite?</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Test</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Files</source>
         <translation></translation>
@@ -1041,30 +1037,6 @@ Do you want to overwrite?</source>
         <source>Full info</source>
         <translation></translation>
     </message>
-    <message>
-        <source>ZIP</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Create new ZIP</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Add to ZIP</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Save ZIP</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>List ZIP content</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Unpack ZIP to current directory</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Images</source>
         <translation></translation>
@@ -1169,18 +1141,6 @@ Do you want to overwrite?</source>
         <source>Docked</source>
         <translation></translation>
     </message>
-    <message>
-        <source>UI mode (TEA restart needed)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>UI language (TEA restart needed)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>UI style (TEA restart needed)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Interface font</source>
         <translation></translation>
@@ -1217,10 +1177,6 @@ Do you want to overwrite?</source>
         <source>TEA program icon</source>
         <translation></translation>
     </message>
-    <message>
-        <source>FIF at the top (restart needed)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Show line numbers</source>
         <translation></translation>
@@ -1281,14 +1237,6 @@ Do you want to overwrite?</source>
         <source>Interface</source>
         <translation>Benutzeroberfläche</translation>
     </message>
-    <message>
-        <source>Use Alt key to access main menu</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Use Left Alt + WASD as additional cursor keys</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Use joystick as cursor keys</source>
         <translation></translation>
@@ -1301,10 +1249,6 @@ Do you want to overwrite?</source>
         <source>Restore the last session on start-up</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Use Enca for charset detection</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Use external image viewer for F2</source>
         <translation></translation>
@@ -1329,14 +1273,6 @@ Do you want to overwrite?</source>
         <source>Charset for file open from command line</source>
         <translation></translation>
     </message>
-    <message>
-        <source>ZIP unpacking: file names charset</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>ZIP packing: file names charset</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Common</source>
         <translation></translation>
@@ -1405,10 +1341,6 @@ Do you want to overwrite?</source>
         <source>Apply hard rotation by EXIF data</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Zip directory with processed images</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Web gallery options</source>
         <translation></translation>
@@ -1559,10 +1491,6 @@ ff=firefox file:///%s</source>
         <source>Refresh</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Guess encoding!</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Save as</source>
         <translation>Speichern unter</translation>
@@ -1644,14 +1572,6 @@ ff=firefox file:///%s</source>
         <source>%1 number of occurrences of %2 is found</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Enter the archive name</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>new_archive</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Open Directory</source>
         <translation></translation>
@@ -1680,10 +1600,6 @@ ff=firefox file:///%s</source>
         <source>There are %1 lines at %2 files</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Enca is not installed, falling back to the built-in detection</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Enter your daily notes here.
 To use time-based reminders, specify the time signature in 24-hour format [hh:mm], i.e.:
@@ -1715,10 +1631,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Total size = %1 kbytes in %2 files&lt;br&gt;</source>
         <translation></translation>
     </message>
-    <message>
-        <source> is unpacked</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Word length: </source>
         <translation></translation>
@@ -1851,6 +1763,54 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Case inverse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable locale only voices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speach voice</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speech</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Say the selected text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speech pause/resume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop speech</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI mode (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI language (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI style (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FIF at the top (restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable speech (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
@@ -1893,11 +1853,4 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>QuaZipFile</name>
-    <message>
-        <source>ZIP/UNZIP API error %1</source>
-        <translation></translation>
-    </message>
-</context>
 </TS>
