@@ -117,7 +117,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Test</source>
-        <translation>Test</translation>
+        <translation type="vanished">Test</translation>
     </message>
     <message>
         <source>Files</source>
@@ -1045,27 +1045,19 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>ZIP</source>
-        <translation>ZIP</translation>
+        <translation type="vanished">ZIP</translation>
     </message>
     <message>
         <source>Create new ZIP</source>
-        <translation>Créer un nouveau ZIP</translation>
+        <translation type="vanished">Créer un nouveau ZIP</translation>
     </message>
     <message>
         <source>Add to ZIP</source>
-        <translation>Ajouter au ZIP</translation>
+        <translation type="vanished">Ajouter au ZIP</translation>
     </message>
     <message>
         <source>Save ZIP</source>
-        <translation>Sauvegarder au ZIP</translation>
-    </message>
-    <message>
-        <source>List ZIP content</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Unpack ZIP to current directory</source>
-        <translation></translation>
+        <translation type="vanished">Sauvegarder au ZIP</translation>
     </message>
     <message>
         <source>Images</source>
@@ -1171,18 +1163,6 @@ Voulez-vous le remplacer ?</translation>
         <source>Docked</source>
         <translation></translation>
     </message>
-    <message>
-        <source>UI mode (TEA restart needed)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>UI language (TEA restart needed)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>UI style (TEA restart needed)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Interface font</source>
         <translation>Police de caractères de l&apos;interface</translation>
@@ -1219,10 +1199,6 @@ Voulez-vous le remplacer ?</translation>
         <source>TEA program icon</source>
         <translation></translation>
     </message>
-    <message>
-        <source>FIF at the top (restart needed)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Show line numbers</source>
         <translation>Montrer les numéros de ligne</translation>
@@ -1283,14 +1259,6 @@ Voulez-vous le remplacer ?</translation>
         <source>Interface</source>
         <translation>Interface</translation>
     </message>
-    <message>
-        <source>Use Alt key to access main menu</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Use Left Alt + WASD as additional cursor keys</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Use joystick as cursor keys</source>
         <translation></translation>
@@ -1303,10 +1271,6 @@ Voulez-vous le remplacer ?</translation>
         <source>Restore the last session on start-up</source>
         <translation>Restaurer la dernière session au lancement</translation>
     </message>
-    <message>
-        <source>Use Enca for charset detection</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Use external image viewer for F2</source>
         <translation></translation>
@@ -1331,14 +1295,6 @@ Voulez-vous le remplacer ?</translation>
         <source>Charset for file open from command line</source>
         <translation></translation>
     </message>
-    <message>
-        <source>ZIP unpacking: file names charset</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>ZIP packing: file names charset</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Common</source>
         <translation>Commun</translation>
@@ -1409,7 +1365,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Zip directory with processed images</source>
-        <translation>Zipper le répertoire avec les images traitées</translation>
+        <translation type="vanished">Zipper le répertoire avec les images traitées</translation>
     </message>
     <message>
         <source>Web gallery options</source>
@@ -1562,10 +1518,6 @@ ff=firefox file:///%s</source>
         <source>Refresh</source>
         <translation>Rafraîchir</translation>
     </message>
-    <message>
-        <source>Guess encoding!</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Save as</source>
         <translation>Sauvegarder en tant que</translation>
@@ -1650,11 +1602,11 @@ ff=firefox file:///%s</source>
     </message>
     <message>
         <source>Enter the archive name</source>
-        <translation>Entrez le nom de l&apos;archive</translation>
+        <translation type="vanished">Entrez le nom de l&apos;archive</translation>
     </message>
     <message>
         <source>new_archive</source>
-        <translation>nouvelle_archive</translation>
+        <translation type="vanished">nouvelle_archive</translation>
     </message>
     <message>
         <source>Open Directory</source>
@@ -1684,10 +1636,6 @@ ff=firefox file:///%s</source>
         <source>There are %1 lines at %2 files</source>
         <translation>Il y a %1 de lignes aux %2 fichiers</translation>
     </message>
-    <message>
-        <source>Enca is not installed, falling back to the built-in detection</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Enter your daily notes here.
 To use time-based reminders, specify the time signature in 24-hour format [hh:mm], i.e.:
@@ -1722,10 +1670,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Total size = %1 kbytes in %2 files&lt;br&gt;</source>
         <translation>Taille totale = %1 ko dans %2 fichiers&lt;br&gt;</translation>
     </message>
-    <message>
-        <source> is unpacked</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Word length: </source>
         <translation></translation>
@@ -1858,6 +1802,54 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Case inverse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable locale only voices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speach voice</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speech</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Say the selected text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speech pause/resume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop speech</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI mode (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI language (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI style (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FIF at the top (restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable speech (TEA restart is needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
@@ -1904,7 +1896,7 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
     <name>QuaZipFile</name>
     <message>
         <source>ZIP/UNZIP API error %1</source>
-        <translation>erreur API ZIP/UNZIP %1</translation>
+        <translation type="vanished">erreur API ZIP/UNZIP %1</translation>
     </message>
 </context>
 </TS>
